summaryrefslogtreecommitdiff
path: root/dns/node.py
diff options
context:
space:
mode:
Diffstat (limited to 'dns/node.py')
-rw-r--r--dns/node.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/dns/node.py b/dns/node.py
index 4f8a16a..8c1802d 100644
--- a/dns/node.py
+++ b/dns/node.py
@@ -40,10 +40,10 @@ class Node(object):
Each rdataset at the node is printed. Any keyword arguments
to this method are passed on to the rdataset's to_text() method.
*name*, a ``dns.name.Name`` or ``text``, the owner name of the
rdatasets.
- Returns a ``text``.
+ Returns a ``str``.
"""
@@ -40,10 +40,10 @@ class Node(object):
Each rdataset at the node is printed. Any keyword arguments
to this method are passed on to the rdataset's to_text() method.
- *name*, a ``dns.name.Name`` or ``text``, the owner name of the
+ *name*, a ``dns.name.Name`` or ``str``, the owner name of the
rdatasets.